
### V1.0.5
- bcpnp: generate company info, employer recommendation letter, employer training, employee training, job description, job offer form xml and rep form xml.
- exp: experience related doc auto generate: resume, employment certificate
- trv: read 5257,1294,1295,5708,5709,5710,and 5645
- recruit: generate job ad, job offer, and recruitment summary
- lmia: generate submission letter, employer training, employee training 
### V1.0.3 
- excel: add function. Now can add any number of excels instead of only 2. sub function is same 
- lmia: submission letter, employer training, employee traning for 5593 5626 5627 
- bcpnp: employer recommendation letter, company info, employer/employee training, job description auto doc makers
- job: job ad, job offer, employment certificate, resume for autodoc makers
